import { Configuration, App, Inject } from '@midwayjs/core';
import * as koa from '@midwayjs/koa';
import * as validate from '@midwayjs/validate';
import * as info from '@midwayjs/info';
import * as swagger from '@midwayjs/swagger';
import * as jwt from '@midwayjs/jwt';
import * as redis from '@midwayjs/redis';
import * as axios from '@midwayjs/axios';
import * as bull from '@midwayjs/bull';
import { join } from 'path';
// freemidway组件项目
import * as FreeFrame from 'free-midway-component';
// 控制器执行前函数
import { CheckTokenMiddleware } from './middleware/checkToken.middleware';
@Configuration({
  imports: [
    FreeFrame,
    validate,
    jwt,
    redis,
    axios,
    swagger,
    bull,
    {
      component: info,
      enabledEnvironment: ['local'],
    },
  ],
  importConfigs: [join(__dirname, './config')],
})
export class ContainerLifeCycle {
  @App()
  app: koa.Application;

  @Inject()
  bullFramework: bull.Framework;

  async onReady() {
    this.app.getMiddleware().insertFirst(CheckTokenMiddleware);
  }
  async onServerReady() {
    // 获取 Processor 相关的队列
    const testQueue = this.bullFramework.getQueue('scheduled');
    // 立即执行这个任务
    await testQueue?.runJob({});
  }
}
