import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { ActivityService } from '../service/activity.service';
import {
  CDTO_activity,
  CVO_activity,
  FVO_activity,
  QDTO_activity,
  QVO_activity,
  UDTO_activity,
  UVAO_activity,
} from '../interface/activity.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['活动'])
@Controller('/activity')
export class ActivityController extends BaseController {
  @Inject()
  service: ActivityService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_activity })
  async create(@Body() data: CDTO_activity) {
    const dbData = await this.service.create(data);
    const result = new CVO_activity(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_activity })
  async query(
    @Query() filter: QDTO_activity,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_activity(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_activity })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_activity(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_activity })
  async update(@Param('id') id: string, @Body() body: UDTO_activity) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
