import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { AdvertService } from '../service/advert.service';
import {
  CDTO_advert,
  CVO_advert,
  FVO_advert,
  QDTO_advert,
  QVO_advert,
  UDTO_advert,
  UVAO_advert,
} from '../interface/advert.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['广告'])
@Controller('/advert')
export class AdvertController extends BaseController {
  @Inject()
  service: AdvertService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_advert })
  async create(@Body() data: CDTO_advert) {
    const dbData = await this.service.create(data);
    const result = new CVO_advert(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_advert })
  async query(
    @Query() filter: QDTO_advert,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, {
      skip,
      limit,
      sort: { sort: 1 },
    });
    const data = [];
    for (const i of list) {
      const newData = new QVO_advert(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_advert })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_advert(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_advert })
  async update(@Param('id') id: string, @Body() body: UDTO_advert) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
