import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { AfterSaleService } from '../service/afterSale.service';
import {
  CDTO_afterSale,
  CVO_afterSale,
  FVO_afterSale,
  QDTO_afterSale,
  QVO_afterSale,
  UDTO_afterSale,
  UVAO_afterSale,
} from '../interface/afterSale.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['售后申请'])
@Controller('/afterSale')
export class AfterSaleController extends BaseController {
  @Inject()
  service: AfterSaleService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_afterSale })
  async create(@Body() data: CDTO_afterSale) {
    const dbData = await this.service.create(data);
    const result = new CVO_afterSale(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_afterSale })
  async query(
    @Query() filter: QDTO_afterSale,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_afterSale(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_afterSale })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_afterSale(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_afterSale })
  async update(@Param('id') id: string, @Body() body: UDTO_afterSale) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
