import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { ArticleService } from '../service/article.service';
import {
  CDTO_article,
  CVO_article,
  FVO_article,
  QDTO_article,
  QVO_article,
  UDTO_article,
  UVAO_article,
} from '../interface/article.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['游玩攻略'])
@Controller('/article')
export class ArticleController extends BaseController {
  @Inject()
  service: ArticleService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_article })
  async create(@Body() data: CDTO_article) {
    const dbData = await this.service.create(data);
    const result = new CVO_article(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_article })
  async query(
    @Query() filter: QDTO_article,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, {
      skip,
      limit,
      sort: { sort: 1 },
    });
    const data = [];
    for (const i of list) {
      const newData = new QVO_article(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/article')
  @ApiQuery({ name: 'query' })
  async article(@Query() filter: any) {
    const list = await this.service.article(filter);
    const data = list.list;
    const total = list.total;
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_article })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_article(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_article })
  async update(@Param('id') id: string, @Body() body: UDTO_article) {
    if (body.status && body.status === '0') await this.service.BeforeUpdate(id);
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.BeforeUpdate(id);
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
