import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { CommentService } from '../service/comment.service';
import {
  CDTO_comment,
  CVO_comment,
  FVO_comment,
  QDTO_comment,
  QVO_comment,
  UDTO_comment,
  UVAO_comment,
} from '../interface/comment.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['评论'])
@Controller('/comment')
export class CommentController extends BaseController {
  @Inject()
  service: CommentService;

  @Get('/exam')
  @ApiResponse({ type: FVO_comment })
  async exam() {
    const list = await this.service.exam();
    return list;
  }

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_comment })
  async create(@Body() data: CDTO_comment) {
    const dbData = await this.service.create(data);
    const result = new CVO_comment(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_comment })
  async query(
    @Query() filter: QDTO_comment,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_comment(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_comment })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_comment(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_comment })
  async update(@Param('id') id: string, @Body() body: UDTO_comment) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
