import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { CouponService } from '../service/coupon.service';
import {
  CDTO_coupon,
  CVO_coupon,
  FVO_coupon,
  QDTO_coupon,
  QVO_coupon,
  UDTO_coupon,
  UVAO_coupon,
} from '../interface/coupon.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['优惠卷'])
@Controller('/coupon')
export class CouponController extends BaseController {
  @Inject()
  service: CouponService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_coupon })
  async create(@Body() data: CDTO_coupon) {
    const dbData = await this.service.create(data);
    const result = new CVO_coupon(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_coupon })
  async query(
    @Query() filter: QDTO_coupon,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_coupon(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/specialQuery')
  @ApiQuery({ name: 'specialQuery' })
  @ApiResponse({ type: QVO_coupon })
  async specialQuery(
    @Query() filter: QDTO_coupon,
    @Query('user') user: string,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = await this.service.makeShowData(list, user);
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_coupon })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_coupon(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_coupon })
  async update(@Param('id') id: string, @Body() body: UDTO_coupon) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
