import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { HotelService } from '../service/hotel.service';
import {
  CDTO_hotel,
  CVO_hotel,
  FVO_hotel,
  QDTO_hotel,
  QVO_hotel,
  UDTO_hotel,
  UVAO_hotel,
} from '../interface/hotel.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['酒店民宿'])
@Controller('/hotel')
export class HotelController extends BaseController {
  @Inject()
  service: HotelService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_hotel })
  async create(@Body() data: CDTO_hotel) {
    const dbData = await this.service.create(data);
    const result = new CVO_hotel(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_hotel })
  async query(
    @Query() filter: QDTO_hotel,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_hotel(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/hotel')
  @ApiQuery({ name: 'query' })
  async hotel(@Query() filter: any) {
    const list = await this.service.hotel(filter);
    const data = list.list;
    const total = list.total;
    return { data, total };
  }

  @Get('/hotel/:id')
  @ApiQuery({ name: 'query' })
  async hotelFetch(@Param('id') id: string, @Query() filter: any) {
    const result = await this.service.hotelFetch(id, filter);
    return result;
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_hotel })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_hotel(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_hotel })
  async update(@Param('id') id: string, @Body() body: UDTO_hotel) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
