import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { LikeService } from '../service/like.service';
import {
  CDTO_like,
  CVO_like,
  FVO_like,
  QDTO_like,
  QVO_like,
  UDTO_like,
  UVAO_like,
} from '../interface/like.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['点赞/收藏'])
@Controller('/like')
export class LikeController extends BaseController {
  @Inject()
  service: LikeService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_like })
  async create(@Body() data: CDTO_like) {
    const dbData = await this.service.create(data);
    const result = new CVO_like(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_like })
  async query(
    @Query() filter: QDTO_like,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_like(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/article')
  @ApiQuery({ name: 'query' })
  async article(@Query() filter: any) {
    const list = await this.service.article(filter);
    const data = list.data;
    const total = list.total;
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_like })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_like(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_like })
  async update(@Param('id') id: string, @Body() body: UDTO_like) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
