import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { LocationService } from '../service/location.service';
import {
  CDTO_location,
  CVO_location,
  FVO_location,
  QDTO_location,
  QVO_location,
  UDTO_location,
  UVAO_location,
} from '../interface/location.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['基础地点'])
@Controller('/location')
export class LocationController extends BaseController {
  @Inject()
  service: LocationService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_location })
  async create(@Body() data: CDTO_location) {
    const dbData = await this.service.create(data);
    const result = new CVO_location(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_location })
  async query(
    @Query() filter: QDTO_location,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_location(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/location')
  @ApiQuery({ name: 'query' })
  async location(@Query() filter: any) {
    const list = await this.service.location(filter);
    const data = list.list;
    const total = list.total;
    return { data, total };
  }

  @Get('/location/:id')
  @ApiQuery({ name: 'query' })
  async locationFetch(@Param('id') id: string, @Query() filter: any) {
    const result = await this.service.locationFetch(id, filter);
    return result;
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_location })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_location(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_location })
  async update(@Param('id') id: string, @Body() body: UDTO_location) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
