import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { ProblemService } from '../service/problem.service';
import {
  CDTO_problem,
  CVO_problem,
  FVO_problem,
  QDTO_problem,
  QVO_problem,
  UDTO_problem,
  UVAO_problem,
} from '../interface/problem.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['常见问题回答'])
@Controller('/problem')
export class ProblemController extends BaseController {
  @Inject()
  service: ProblemService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_problem })
  async create(@Body() data: CDTO_problem) {
    const dbData = await this.service.create(data);
    const result = new CVO_problem(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_problem })
  async query(
    @Query() filter: QDTO_problem,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_problem(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_problem })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_problem(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_problem })
  async update(@Param('id') id: string, @Body() body: UDTO_problem) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
