import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import {
  BaseController,
  FrameworkErrorEnum,
  ServiceError,
} from 'free-midway-component';
import { RoleService } from '../service/role.service';
import {
  CDTO_role,
  CVO_role,
  FVO_role,
  QDTO_role,
  QVO_role,
  UDTO_role,
  UVAO_role,
} from '../interface/role.interface';
import {
  ApiOperation,
  ApiResponse,
  ApiTags,
  ApiQuery,
} from '@midwayjs/swagger';
import { AdminService } from '../service/admin.service';
import { MenusService } from '../service/menus.service';
import { Validate } from '@midwayjs/validate';
import get = require('lodash/get');
@ApiTags(['角色'])
@Controller('/role')
export class RoleController extends BaseController {
  @Inject()
  service: RoleService;

  @Inject()
  adminService: AdminService;

  @Inject()
  menusService: MenusService;

  @Get('/um')
  @ApiOperation({ description: '获取用户的菜单' })
  async userMenu() {
    const user = this.ctx.user;
    if (!user)
      throw new ServiceError('用户未登录', FrameworkErrorEnum.NOT_LOGIN);
    const roleInfo = await this.service.fetch(get(user, 'role'));
    const menus = await this.service.getMenuByRoles(get(roleInfo, 'menu', []));
    return menus;
  }
  @Get('/am')
  @ApiOperation({ description: '获取所有菜单提供选择' })
  async roleAllMenu() {
    const menusList = await this.menusService.queryMenu();
    return menusList;
  }

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_role })
  async create(@Body() data: CDTO_role) {
    const dbData = await this.service.create(data);
    const result = new CVO_role(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_role })
  async query(
    @Query() filter: QDTO_role,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_role(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_role })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_role(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_role })
  async update(@Param('id') id: string, @Body() body: UDTO_role) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
