import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { TicketService } from '../service/ticket.service';
import {
  CDTO_ticket,
  CVO_ticket,
  FVO_ticket,
  QDTO_ticket,
  QVO_ticket,
  UDTO_ticket,
  UVAO_ticket,
} from '../interface/ticket.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['景区门票'])
@Controller('/ticket')
export class TicketController extends BaseController {
  @Inject()
  service: TicketService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_ticket })
  async create(@Body() data: CDTO_ticket) {
    const dbData = await this.service.create(data);
    const result = new CVO_ticket(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_ticket })
  async query(
    @Query() filter: QDTO_ticket,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_ticket(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/queryDate')
  @ApiQuery({ name: 'queryDate' })
  @ApiResponse({ type: QVO_ticket })
  async queryDate(@Query() filter: any) {
    const list = await this.service.queryDate(filter);
    const data = [];
    for (const i of list.data) {
      const newData = new QVO_ticket(i);
      data.push(newData);
    }
    const total = list.total;
    return { data, total };
  }

  @Get('/ticket/:id')
  @ApiQuery({ name: 'query' })
  async ticket(@Param('id') id: string, @Query() filter: any) {
    const result = await this.service.ticket(id, filter);
    return result;
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_ticket })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_ticket(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_ticket })
  async update(@Param('id') id: string, @Body() body: UDTO_ticket) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
