import {
  Config,
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { UserService } from '../service/user.service';
import {
  CDTO_user,
  CVO_user,
  FVO_user,
  QDTO_user,
  QVO_user,
  UDTO_user,
  UVAO_user,
  LoginVO,
} from '../interface/user.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
import { JwtService } from '@midwayjs/jwt';
@ApiTags(['用户'])
@Controller('/user')
export class UserController extends BaseController {
  @Inject()
  service: UserService;

  @Inject()
  jwtService: JwtService;

  @Config('jwt.secret')
  jwtSecret;

  @Config('jwt.expiresIn')
  jwtExpiresIn;

  @Get('/login')
  @ApiResponse({ type: FVO_user })
  async wxLogin(@Query('openid') openid: string) {
    const data = await this.service.wxLogin(openid);
    let vo = new LoginVO(data);
    vo = JSON.parse(JSON.stringify(vo));
    const token = await this.jwtService.sign(vo, this.jwtSecret, {
      expiresIn: this.jwtExpiresIn,
    });
    return token;
  }

  @Get('/statistics')
  @ApiResponse({ type: FVO_user })
  async statistics(@Query('user') user: string) {
    const list = await this.service.statistics(user);
    return list;
  }

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_user })
  async create(@Body() data: CDTO_user) {
    const dbData = await this.service.create(data);
    const result = new CVO_user(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_user })
  async query(
    @Query() filter: QDTO_user,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_user(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/user')
  @ApiQuery({ name: 'query' })
  async user(@Query() filter: any) {
    const list = await this.service.user(filter);
    const data = list.list;
    const total = list.total;
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_user })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_user(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_user })
  async update(@Param('id') id: string, @Body() body: UDTO_user) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
