import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { UserCouponService } from '../service/userCoupon.service';
import {
  CDTO_userCoupon,
  CVO_userCoupon,
  FVO_userCoupon,
  QDTO_userCoupon,
  QVO_userCoupon,
  UDTO_userCoupon,
  UVAO_userCoupon,
} from '../interface/userCoupon.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['领取优惠卷记录'])
@Controller('/userCoupon')
export class UserCouponController extends BaseController {
  @Inject()
  service: UserCouponService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_userCoupon })
  async create(@Body() data: CDTO_userCoupon) {
    await this.service.createBefore(data);
    const dbData = await this.service.create(data);
    const result = new CVO_userCoupon(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_userCoupon })
  async query(
    @Query() filter: QDTO_userCoupon,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_userCoupon(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/specialQuery')
  @ApiQuery({ name: 'specialQuery' })
  @ApiResponse({ type: QDTO_userCoupon })
  async specialQuery(
    @Query() filter: QDTO_userCoupon,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = await this.service.makeShowData(list);
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_userCoupon })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_userCoupon(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_userCoupon })
  async update(@Param('id') id: string, @Body() body: UDTO_userCoupon) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
