import { Rule, RuleType } from '@midwayjs/validate';
import { ApiProperty } from '@midwayjs/swagger';
import {
  FrameworkErrorEnum,
  SearchBase,
  ServiceError,
} from 'free-midway-component';
import get = require('lodash/get');
const dealVO = (cla, data) => {
  for (const key in cla) {
    const val = get(data, key);
    if (val || val === 0) cla[key] = val;
  }
};
export class FVO_article {
  constructor(data: object) {
    dealVO(this, data);
  }
  @ApiProperty({ description: '数据id' })
  _id: string = undefined;
  @ApiProperty({ description: '发布人' })
  'contact': string = undefined;
  @ApiProperty({ description: '发布姓名' })
  'contact_name': string = undefined;
  @ApiProperty({ description: '标题' })
  'title': string = undefined;
  @ApiProperty({ description: '图片' })
  'file': Array<any> = undefined;
  @ApiProperty({ description: '内容' })
  'content': string = undefined;
  @ApiProperty({ description: '类型' })
  'type': string = undefined;
  @ApiProperty({ description: '创建时间' })
  'create_time': string = undefined;
  @ApiProperty({ description: '排序' })
  'sort': number = undefined;
  @ApiProperty({ description: '点赞数' })
  'like_num': number = undefined;
  @ApiProperty({ description: '是否启用' })
  'is_use': string = undefined;
  @ApiProperty({ description: '状态' })
  'status': string = undefined;
}

export class QDTO_article extends SearchBase {
  constructor() {
    const like_prop = ['title', 'contact_name'];
    const props = ['contact', 'type', 'sort', 'like_num', 'is_use', 'status'];
    const mapping = [];
    super({ like_prop, props, mapping });
  }
  @ApiProperty({ description: '发布人' })
  'contact': string = undefined;
  @ApiProperty({ description: '发布人姓名' })
  'contact_name': string = undefined;
  @ApiProperty({ description: '标题' })
  'title': string = undefined;
  @ApiProperty({ description: '类型' })
  'type': string = undefined;
  @ApiProperty({ description: '排序' })
  'sort': number = undefined;
  @ApiProperty({ description: '点赞数' })
  'like_num': number = undefined;
  @ApiProperty({ description: '是否启用' })
  'is_use': string = undefined;
  @ApiProperty({ description: '状态' })
  'status': string = undefined;
}

export class QVO_article extends FVO_article {
  constructor(data: object) {
    super(data);
    dealVO(this, data);
  }
}

export class CDTO_article {
  @ApiProperty({ description: '发布人' })
  @Rule(
    RuleType['string']()
      .required()
      .error(new ServiceError('缺少发布人', FrameworkErrorEnum.NEED_BODY))
  )
  'contact': string = undefined;
  @ApiProperty({ description: '发布人姓名' })
  @Rule(RuleType['string']().empty(''))
  'contact_name': string = undefined;
  @ApiProperty({ description: '标题' })
  @Rule(RuleType['string']().empty(''))
  'title': string = undefined;
  @ApiProperty({ description: '内容' })
  @Rule(RuleType['string']().empty(''))
  'content': string = undefined;
  @ApiProperty({ description: '图片' })
  @Rule(RuleType['array']().empty(''))
  'file': Array<any> = undefined;
  @ApiProperty({ description: '类型' })
  @Rule(RuleType['string']().empty(''))
  'type': string = undefined;
  @ApiProperty({ description: '创建时间' })
  @Rule(RuleType['string']().empty(''))
  'create_time': string = undefined;
  @ApiProperty({ description: '排序' })
  @Rule(RuleType['number']().empty(''))
  'sort': number = undefined;
  @ApiProperty({ description: '点赞数' })
  @Rule(RuleType['number']().empty(''))
  'like_num': number = undefined;
  @ApiProperty({ description: '是否启用' })
  @Rule(RuleType['string']().empty(''))
  'is_use': string = undefined;
  @ApiProperty({ description: '状态' })
  @Rule(RuleType['string']().empty(''))
  'status': string = undefined;
}

export class CVO_article extends FVO_article {
  constructor(data: object) {
    super(data);
    dealVO(this, data);
  }
}

export class UDTO_article extends CDTO_article {
  @ApiProperty({ description: '数据id' })
  @Rule(RuleType['string']().empty(''))
  _id: string = undefined;
}

export class UVAO_article extends FVO_article {
  constructor(data: object) {
    super(data);
    dealVO(this, data);
  }
}
