import { Rule, RuleType } from '@midwayjs/validate';
import { ApiProperty } from '@midwayjs/swagger';
import {
  FrameworkErrorEnum,
  SearchBase,
  ServiceError,
} from 'free-midway-component';
import get = require('lodash/get');
const dealVO = (cla, data) => {
  for (const key in cla) {
    const val = get(data, key);
    if (val || val === 0) cla[key] = val;
  }
};
export class FVO_user {
  constructor(data: object) {
    dealVO(this, data);
  }
  @ApiProperty({ description: '数据id' })
  _id: string = undefined;
  @ApiProperty({ description: 'openid' })
  'openid': string = undefined;
  @ApiProperty({ description: '真实姓名' })
  'name': string = undefined;
  @ApiProperty({ description: '昵称' })
  'nick_name': string = undefined;
  @ApiProperty({ description: '个人头像' })
  'logo': Array<any> = undefined;
  @ApiProperty({ description: '性别' })
  'gender': string = undefined;
  @ApiProperty({ description: '手机号' })
  'phone': string = undefined;
  @ApiProperty({ description: '生日' })
  'birthday': string = undefined;
  @ApiProperty({ description: '用户类型' })
  'type': string = undefined;
  @ApiProperty({ description: '所在城市' })
  'city': string = undefined;
  @ApiProperty({ description: '状态' })
  'status': string = undefined;
}

export class QDTO_user extends SearchBase {
  constructor() {
    const like_prop = [];
    const props = [
      'openid',
      'name',
      'nick_name',
      'type',
      'status',
      'phone',
      'city',
    ];
    const mapping = [];
    super({ like_prop, props, mapping });
  }
  @ApiProperty({ description: 'openid' })
  'openid': string = undefined;
  @ApiProperty({ description: '真实姓名' })
  'name': string = undefined;
  @ApiProperty({ description: '昵称' })
  'nick_name': string = undefined;
  @ApiProperty({ description: '手机号' })
  'phone': string = undefined;
  @ApiProperty({ description: '用户类型' })
  'type': string = undefined;
  @ApiProperty({ description: '所在城市' })
  'city': string = undefined;
  @ApiProperty({ description: '状态' })
  'status': string = undefined;
}

export class QVO_user extends FVO_user {
  constructor(data: object) {
    super(data);
    dealVO(this, data);
  }
}

export class CDTO_user {
  @ApiProperty({ description: 'openid' })
  @Rule(
    RuleType['string']()
      .required()
      .error(new ServiceError('缺少openid', FrameworkErrorEnum.NEED_BODY))
  )
  'openid': string = undefined;
  @ApiProperty({ description: '真实姓名' })
  @Rule(RuleType['string']().empty(''))
  'name': string = undefined;
  @ApiProperty({ description: '昵称' })
  @Rule(RuleType['string']().empty(''))
  'nick_name': string = undefined;
  @ApiProperty({ description: '个人头像' })
  @Rule(RuleType['array']().empty(''))
  'logo': Array<any> = undefined;
  @ApiProperty({ description: '性别' })
  @Rule(RuleType['string']().empty(''))
  'gender': string = undefined;
  @ApiProperty({ description: '手机号' })
  @Rule(RuleType['string']().empty(''))
  'phone': string = undefined;
  @ApiProperty({ description: '生日' })
  @Rule(RuleType['string']().empty(''))
  'birthday': string = undefined;
  @ApiProperty({ description: '用户类型' })
  @Rule(RuleType['string']().empty(''))
  'type': string = undefined;
  @ApiProperty({ description: '所在城市' })
  @Rule(RuleType['string']().empty(''))
  'city': string = undefined;
  @ApiProperty({ description: '状态' })
  @Rule(RuleType['string']().empty(''))
  'status': string = undefined;
}

export class CVO_user extends FVO_user {
  constructor(data: object) {
    super(data);
    dealVO(this, data);
  }
}

export class UDTO_user extends CDTO_user {
  @ApiProperty({ description: '数据id' })
  @Rule(RuleType['string']().empty(''))
  _id: string = undefined;
}

export class UVAO_user extends FVO_user {
  constructor(data: object) {
    super(data);
    dealVO(this, data);
  }
}

export class LoginVO {
  constructor(data: object) {
    for (const key of Object.keys(this)) {
      this[key] = get(data, key);
    }
  }
  @ApiProperty({ description: '数据id' })
  _id: string = undefined;
  @ApiProperty({ description: 'openid' })
  'openid': string = undefined;
  @ApiProperty({ description: '真实姓名' })
  'name': string = undefined;
  @ApiProperty({ description: '昵称' })
  'nick_name': string = undefined;
  @ApiProperty({ description: '个人头像' })
  'logo': Array<any> = undefined;
  @ApiProperty({ description: '性别' })
  'gender': string = undefined;
  @ApiProperty({ description: '手机号' })
  'phone': string = undefined;
  @ApiProperty({ description: '生日' })
  'birthday': string = undefined;
  @ApiProperty({ description: '用户类型' })
  'type': string = undefined;
  @ApiProperty({ description: '所在城市' })
  'city': string = undefined;
}
