import { Processor, IProcessor } from '@midwayjs/bull';
import { FORMAT } from '@midwayjs/core';
import { InjectEntityModel } from '@midwayjs/typegoose';
import { ReturnModelType } from '@typegoose/typegoose';
import { Ticket } from '../entity/ticket.entity';
import { Coupon } from '../entity/coupon.entity';
const moment = require('moment');
@Processor('scheduled', {
  // 每天凌晨12点执行一次检查过期的门票
  repeat: {
    cron: FORMAT.CRONTAB.EVERY_DAY,
  },
  removeOnComplete: 3, // 成功后移除任务记录，最多保留最近 3 条记录
  removeOnFail: 10, // 失败后移除任务记录
})
export class TestProcessor implements IProcessor {
  @InjectEntityModel(Ticket)
  tmodel: ReturnModelType<typeof Ticket>;

  @InjectEntityModel(Coupon)
  cModel: ReturnModelType<typeof Coupon>;

  async execute() {
    const date = moment().format('YYYY-MM-DD');
    // 判断门票是否过期
    let ticket = await this.tmodel.find({ is_use: '0' });
    const ticketTotal = await this.tmodel.count({ is_use: '0' });
    if (ticketTotal > 0) ticket = JSON.parse(JSON.stringify(ticket));
    ticket.forEach(async item => {
      // 判断日期是否在开始日期和结束日期中间，并且可能是开始日期或者结束日期
      const startDate = item.date[0];
      const endDate = item.date[1];
      const format = 'YYYY-MM-DD';
      const diffStart =
        moment(startDate, format).diff(moment(date, format), 'days') <= 0;
      const diffEnd =
        moment(endDate, format).diff(moment(date, format), 'days') >= 0;
      const diffDtate = diffStart && diffEnd;
      if (!diffDtate) {
        await this.tmodel.updateOne({ _id: item._id }, { is_use: '1' });
      }
    });
    // 判断优惠券是否过期
    let coupon = await this.cModel.find({
      is_use: '0',
      expire_type: 'fixed',
    });
    const couponTotal = await this.cModel.count({
      is_use: '0',
      expire_type: 'fixed',
    });
    if (couponTotal > 0) coupon = JSON.parse(JSON.stringify(coupon));
    coupon.forEach(async item => {
      // 判断日期是否在开始日期和结束日期中间，并且可能是开始日期或者结束日期
      const startDate = item.expire_config[0];
      const endDate = item.expire_config[1];
      const format = 'YYYY-MM-DD';
      const diffStart =
        moment(startDate, format).diff(moment(date, format), 'days') <= 0;
      const diffEnd =
        moment(endDate, format).diff(moment(date, format), 'days') >= 0;
      const diffDtate = diffStart && diffEnd;
      if (!diffDtate) {
        await this.cModel.updateOne({ _id: item._id }, { is_use: '1' });
      }
    });
  }
}
