import { Provide } from '@midwayjs/decorator';
import { InjectEntityModel } from '@midwayjs/typegoose';
import { ReturnModelType } from '@typegoose/typegoose';
import {
  BaseService,
  FrameworkErrorEnum,
  ServiceError,
} from 'free-midway-component';
import { Admin } from '../entity/admin.entity';
import isEqual = require('lodash/isEqual');
import { LoginDTO } from '../interface/admin.interface';
type modelType = ReturnModelType<typeof Admin>;
@Provide()
export class AdminService extends BaseService<modelType> {
  @InjectEntityModel(Admin)
  model: modelType;

  async findUserToLogin(data: LoginDTO): Promise<object> {
    const { account, password } = data;
    const user = await this.model.findOne({ account }, '+password').lean();
    if (!user)
      throw new ServiceError(
        '未找到管理员信息',
        FrameworkErrorEnum.NOT_FOUND_DATA
      );
    if (!isEqual(user.password.secret, password))
      throw new ServiceError('密码错误', FrameworkErrorEnum.SERVICE_FAULT);
    if (user.status === '0')
      throw new ServiceError(
        '账号审核中,请稍后再试',
        FrameworkErrorEnum.SERVICE_FAULT
      );
    if (user.status === '2')
      throw new ServiceError(
        '账号审核拒绝,请重新申请',
        FrameworkErrorEnum.SERVICE_FAULT
      );
    return user;
  }
}
