import { Provide } from '@midwayjs/decorator';
import { InjectEntityModel } from '@midwayjs/typegoose';
import { ReturnModelType } from '@typegoose/typegoose';
import { BaseService } from 'free-midway-component';
import { Coupon } from '../entity/coupon.entity';
import { DictData } from '../entity/dictData.entity';
import { UserCoupon } from '../entity/userCoupon.entity';
import _ = require('lodash');
import { Types } from 'mongoose';
const ObjectId = Types.ObjectId;
type modelType = ReturnModelType<typeof Coupon>;
@Provide()
export class CouponService extends BaseService<modelType> {
  @InjectEntityModel(Coupon)
  model: modelType;

  @InjectEntityModel(DictData)
  dModel: ReturnModelType<typeof DictData>;

  @InjectEntityModel(UserCoupon)
  userCouponModel: ReturnModelType<typeof UserCoupon>;

  // 转换为显示的格式
  async makeShowData(couponList, user) {
    // 过期字典
    const expList = await this.dModel.find({ type: 'coupon_expire_type' });
    // 减免字典
    const disList = await this.dModel.find({ type: 'coupon_discount_type' });
    // 使用字典
    const useList = await this.dModel.find({ type: 'coupon_use_limit' });
    // 领取字典
    const getList = await this.dModel.find({ type: 'coupon_get_limit' });
    const list = [];
    for (const i of couponList) {
      const { _id, meta, is_use, brief, ...coupon } = i;
      let obj: any = { _id, name: _.get(coupon, 'name'), brief, meta, is_use };
      const UserCoupon = await this.userCouponModel.count({
        coupon: new ObjectId(_id).toString(),
        user: user,
      });
      if (UserCoupon > 0) obj.is_receive = true;
      else obj.is_receive = false;
      // 失效
      const expire_type = _.get(coupon, 'expire_type');
      const expire_type_label = _.get(
        expList.find(f => f.value === expire_type),
        'label'
      );
      let days;
      let expire_time = _.get(coupon, `expire_config.${expire_type}`);
      if (expire_time) {
        if (expire_type === 'fixed') expire_time = expire_time.join(' 至 ');
        else {
          days = expire_time;
          expire_time = `领取日当天-领取后${expire_time}天`;
        }
      }
      obj = { ...obj, days, expire_type, expire_type_label, expire_time };
      // 减免
      const discount_type = _.get(coupon, 'discount_type');
      const discount_type_label = _.get(
        disList.find(f => f.value === discount_type),
        'label'
      );
      const discount_config = _.get(coupon, 'discount_config');
      obj = { ...obj, discount_type, discount_type_label, discount_config };
      // 使用
      const use_limit = _.get(coupon, 'use_limit');
      const use_limit_label = _.get(
        useList.find(f => f.value === use_limit),
        'label'
      );
      const use_limit_config = _.get(coupon, 'use_limit_config');
      obj = { ...obj, use_limit, use_limit_label, use_limit_config };
      // 领取
      const get_limit = _.get(coupon, 'get_limit');
      const get_limit_label = _.get(
        getList.find(f => f.value === get_limit),
        'label'
      );
      const get_limit_config = _.get(coupon, 'get_limit_config');
      obj = { ...obj, get_limit, get_limit_label, get_limit_config };
      list.push(obj);
    }
    return list;
  }
}
