import { Provide, Inject } from '@midwayjs/decorator';
import { InjectEntityModel } from '@midwayjs/typegoose';
import { ReturnModelType } from '@typegoose/typegoose';
import { BaseService } from 'free-midway-component';
import { Order } from '../entity/order.entity';
import { UserCoupon } from '../entity/userCoupon.entity';
import _ = require('lodash');
import { Hotel } from '../entity/hotel.entity';
import { Ticket } from '../entity/ticket.entity';
import { Coupon } from '../entity/coupon.entity';
import { CountUtilService } from '../service/util/count.util';
type modelType = ReturnModelType<typeof Order>;
@Provide()
export class OrderService extends BaseService<modelType> {
  @InjectEntityModel(Order)
  model: modelType;

  @InjectEntityModel(UserCoupon)
  uModel: ReturnModelType<typeof UserCoupon>;

  @InjectEntityModel(Coupon)
  cModel: ReturnModelType<typeof Coupon>;

  @InjectEntityModel(Hotel)
  hModel: ReturnModelType<typeof Hotel>;

  @InjectEntityModel(Ticket)
  tModel: ReturnModelType<typeof Ticket>;

  @Inject()
  countUtil: CountUtilService;

  // 创建总订单前
  async createBefore(data) {
    const { discount } = data;
    // 计算有优惠券的优惠金额和总金额
    if (discount) {
      const UserCoupon = await this.uModel.findById(discount);
      if (UserCoupon) {
        const coupon = await this.cModel.findById(_.get(UserCoupon, 'coupon'));
        const { discount_type, discount_config, get_limit } = coupon;
        // 满减
        if (discount_type === 'min') {
          // 无限制
          if (get_limit === 'nolimit') {
            data.coupon_money = _.get(discount_config, 'min');
            data.total_money = await this.countUtil.minus(
              data.money,
              data.coupon_money
            );
          }
        } else if (discount_type === 'discount') {
          // 折扣
        }
      }
    } else {
      // 没有优惠券的优惠金额和总金额
      data.coupon_money = 0;
      data.total_money = data.money;
    }
    return data;
  }

  // 创建总订单后
  async createAfter(data) {
    const { source, type, identity, discount } = data;
    // 如果使用优惠券 需要修改优惠券状态
    if (discount) {
      const UserCoupon = await this.uModel.findById(discount);
      if (UserCoupon)
        await this.uModel.updateOne({ _id: discount }, { is_use: '1' });
    }
    // 来源加销售数量
    if (source) {
      if (type === '0') {
        const hotel = await this.hModel.findById(_.get(source, '_id'));
        if (hotel)
          await this.hModel.updateOne(
            { _id: _.get(source, '_id') },
            { buy_num: _.get(hotel, 'buy_num') + identity.length }
          );
      } else if (type === '1') {
        const ticket = await this.tModel.findById(_.get(source, '_id'));
        if (ticket)
          await this.tModel.updateOne(
            { _id: _.get(source, '_id') },
            { buy_num: _.get(ticket, 'buy_num') + identity.length }
          );
      }
    }
  }
}
