import { Provide } from '@midwayjs/decorator';
import { InjectEntityModel } from '@midwayjs/typegoose';
import { ReturnModelType } from '@typegoose/typegoose';
import { BaseService } from 'free-midway-component';
import { Ticket } from '../entity/ticket.entity';
import { Like } from '../entity/like.entity';
const moment = require('moment');
import { Types } from 'mongoose';
const ObjectId = Types.ObjectId;
type modelType = ReturnModelType<typeof Ticket>;
@Provide()
export class TicketService extends BaseService<modelType> {
  @InjectEntityModel(Ticket)
  model: modelType;

  @InjectEntityModel(Like)
  lModel: ReturnModelType<typeof Like>;

  // 日期查询
  async queryDate(filter) {
    const { skip = 0, limit, date, ...info } = filter;
    const list: any = await this.model
      .find(info)
      .skip(skip)
      .limit(limit)
      .lean();
    const data = [];
    for (const val of list) {
      if (date) {
        // 判断日期是否在开始日期和结束日期中间，并且可能是开始日期或者结束日期
        const startDate = val.date[0];
        const endDate = val.date[1];
        const format = 'YYYY-MM-DD';
        const diffStart =
          moment(startDate, format).diff(moment(date, format), 'days') <= 0;
        const diffEnd =
          moment(endDate, format).diff(moment(date, format), 'days') >= 0;
        const diffDtate = diffStart && diffEnd;
        if (diffDtate) data.push(val);
      } else data.push(val);
    }
    const total = data.length;
    return { data, total };
  }

  // 查看收藏或点赞详情
  async ticket(id, filter) {
    const { user } = filter;
    const data: any = await this.model.findById(id).lean();
    // 查询收藏喜欢表
    const result1: any = await this.lModel
      .findOne({
        source: id,
        user: user,
        type: '0',
      })
      .lean();
    const result2: any = await this.lModel
      .findOne({
        source: id,
        user: user,
        type: '1',
      })
      .lean();
    if (result1) {
      data.is_like = true;
      data.like = new ObjectId(result1._id).toString();
    } else data.is_like = false;
    data.like_num = await this.lModel.count({
      type: '0',
      source: new ObjectId(data._id).toString(),
    });
    if (result2) {
      data.is_collect = true;
      data.collect = new ObjectId(result2._id).toString();
    } else data.is_collect = false;
    data.collect_num = await this.lModel.count({
      type: '1',
      source: new ObjectId(data._id).toString(),
    });
    return data;
  }
}
