import { Provide } from '@midwayjs/decorator';
import { InjectEntityModel } from '@midwayjs/typegoose';
import { ReturnModelType } from '@typegoose/typegoose';
import {
  BaseService,
  FrameworkErrorEnum,
  ServiceError,
} from 'free-midway-component';
import { User } from '../entity/user.entity';
import { Comment } from '../entity/comment.entity';
import { Like } from '../entity/like.entity';
import { Chat } from '../entity/chat.entity';
import { Types } from 'mongoose';
import _ = require('lodash');
const ObjectId = Types.ObjectId;
type modelType = ReturnModelType<typeof User>;
@Provide()
export class UserService extends BaseService<modelType> {
  @InjectEntityModel(User)
  model: modelType;

  @InjectEntityModel(Comment)
  cModel: ReturnModelType<typeof Comment>;

  @InjectEntityModel(Like)
  lModel: ReturnModelType<typeof Like>;

  @InjectEntityModel(Chat)
  chatModel: ReturnModelType<typeof Chat>;

  async wxLogin(openid: string): Promise<object> {
    let user = await this.model.findOne({ openid }).lean();
    if (!user) user = await this.model.create({ openid });
    const status = _.get(user, 'status');
    if (status === '0')
      throw new ServiceError(
        '账号审核中，请稍后再试',
        FrameworkErrorEnum.NOT_FOUND_DATA
      );
    else if (status === '2')
      throw new ServiceError(
        '账号审核已注销！',
        FrameworkErrorEnum.NOT_FOUND_DATA
      );
    return user;
  }
  // 我的页面显示我的收藏/评论/点赞
  async statistics(user: string): Promise<object> {
    const comment = await this.cModel.count({ user }).lean();
    const like = await this.lModel.count({ user, type: '0' }).lean();
    const collect = await this.lModel.count({ user, type: '1' }).lean();
    const list = [
      {
        title: '点赞',
        route: 'pagesIndex/like/index',
        type: '0',
        num: like,
      },
      {
        title: '收藏',
        route: 'pagesIndex/collect/index',
        type: '1',
        num: collect,
      },
      {
        title: '评论',
        route: 'pagesIndex/comment/index',
        type: '2',
        num: comment,
      },
    ];
    return list;
  }

  async user(filter) {
    const { skip = 0, limit, ...info } = filter;
    const list: any = await this.model
      .find(info)
      .skip(skip)
      .limit(limit)
      .lean();
    const total = await this.model.count(info);
    for (const val of list) {
      const result = await this.chatModel
        .find({
          user: new ObjectId(val._id).toString(),
          speaker: new ObjectId(val._id).toString(),
          is_read: '0',
        })
        .lean();
      if (result.length > 0) val.is_read = '未读';
      else val.is_read = '已读';
    }
    return { list, total };
  }
}
