import { Provide } from '@midwayjs/decorator';
import { InjectEntityModel } from '@midwayjs/typegoose';
import { ReturnModelType } from '@typegoose/typegoose';
import {
  BaseService,
  FrameworkErrorEnum,
  ServiceError,
} from 'free-midway-component';
import { UserCoupon } from '../entity/userCoupon.entity';
import { DictData } from '../entity/dictData.entity';
import _ = require('lodash');
import { Coupon } from '../entity/coupon.entity';
type modelType = ReturnModelType<typeof UserCoupon>;
@Provide()
export class UserCouponService extends BaseService<modelType> {
  @InjectEntityModel(UserCoupon)
  model: modelType;

  @InjectEntityModel(DictData)
  dictDataModel: ReturnModelType<typeof DictData>;

  @InjectEntityModel(Coupon)
  couponModel: ReturnModelType<typeof Coupon>;

  // 领取优惠券前
  async createBefore(data) {
    const { coupon } = data;
    const couponInfo: any = await this.couponModel.findById(coupon);
    if (couponInfo) {
      if (couponInfo.num === 0) {
        throw new ServiceError(
          '您手慢了,没抢到',
          FrameworkErrorEnum.NOT_FOUND_DATA
        );
      } else {
        await this.couponModel.updateOne(
          { _id: coupon },
          { num: couponInfo.num - 1 }
        );
      }
      if (_.get(couponInfo, 'get_limit') === 'max') {
        // 如果限制每人限领多少张
        const userCoupon: any = await this.model.count({ coupon });
        const config = _.get(couponInfo, 'get_limit_config');
        const num = _.get(config, 'max');
        if (userCoupon >= num) {
          throw new ServiceError(
            `每人限制领取${num}张`,
            FrameworkErrorEnum.SERVICE_FAULT
          );
        }
      }
    } else {
      throw new ServiceError(
        '没有找到优惠券！',
        FrameworkErrorEnum.NOT_FOUND_DATA
      );
    }
  }

  // 转换为显示的格式
  async makeShowData(couponList) {
    // 过期字典
    const expList = await this.dictDataModel.find({
      type: 'coupon_expire_type',
    });
    // 减免字典
    const disList = await this.dictDataModel.find({
      type: 'coupon_discount_type',
    });
    // 使用字典
    const useList = await this.dictDataModel.find({ type: 'coupon_use_limit' });
    // 领取字典
    const getList = await this.dictDataModel.find({ type: 'coupon_get_limit' });
    const list = [];
    for (const i of couponList) {
      const { coupon } = i;
      let obj: any = {
        ...i,
        brief: _.get(coupon, 'brief'),
        name: _.get(coupon, 'name'),
        type: _.get(coupon, 'type'),
      };
      // 失效
      const expire_type = _.get(coupon, 'expire_type');
      const expire_type_label = _.get(
        expList.find(f => f.value === expire_type),
        'label'
      );
      let days;
      let expire_time = _.get(coupon, `expire_config.${expire_type}`);
      if (expire_time) {
        if (expire_type === 'fixed') expire_time = expire_time.join(' 至 ');
        else {
          days = expire_time;
          expire_time = `领取日当天-领取后${expire_time}天`;
        }
      }
      obj = { ...obj, days, expire_type, expire_type_label, expire_time };
      // 减免
      const discount_type = _.get(coupon, 'discount_type');
      const discount_type_label = _.get(
        disList.find(f => f.value === discount_type),
        'label'
      );
      const discount_config = _.get(coupon, 'discount_config');
      obj = { ...obj, discount_type, discount_type_label, discount_config };
      // 使用
      const use_limit = _.get(coupon, 'use_limit');
      const use_limit_label = _.get(
        useList.find(f => f.value === use_limit),
        'label'
      );
      const use_limit_config = _.get(coupon, 'use_limit_config');
      obj = { ...obj, use_limit, use_limit_label, use_limit_config };
      // 领取
      const get_limit = _.get(coupon, 'get_limit');
      const get_limit_label = _.get(
        getList.find(f => f.value === get_limit),
        'label'
      );
      const get_limit_config = _.get(coupon, 'get_limit_config');
      obj = { ...obj, get_limit, get_limit_label, get_limit_config };
      list.push(obj);
    }
    return list;
  }
}
