import { Provide } from '@midwayjs/decorator';
import { InjectEntityModel } from '@midwayjs/typegoose';
import { ReturnModelType } from '@typegoose/typegoose';
import { FrameworkErrorEnum, ServiceError } from 'free-midway-component';
import { Admin } from '../../entity/admin.entity';
import {
  CheckAccountExist,
  CheckUpdateAccount,
} from '../../interface/util/user.util.interface';

@Provide()
export class UserUtilService {
  @InjectEntityModel(Admin)
  adminModel: ReturnModelType<typeof Admin>;

  /**
   * 检查创建时,账号
   * @param data 参数
   */
  async checkAccount(data: CheckAccountExist) {
    const adminan = await this.adminModel.count({ account: data.account });
    if (adminan > 0)
      throw new ServiceError(
        '该账号已存在于用户中',
        FrameworkErrorEnum.BAD_BODY
      );
  }
  /**
   * 检查修改时,账号
   * @param id 当前要修改的数据
   * @param data 参数
   */
  async checkUpdateAccount(id, data: CheckUpdateAccount) {
    const { account } = data;
    const admincn = await this.adminModel.count({
      _id: { $ne: id },
      account,
    });
    if (admincn > 0)
      throw new ServiceError(
        '该账号已存在于用户中',
        FrameworkErrorEnum.BAD_BODY
      );
  }
}
